@@ -199,6 +199,36 @@ void ProcessControl::start()
         qCDebug(AKONADICONTROL_LOG) << "============================================================";
         qCDebug(AKONADICONTROL_LOG);
     }
+
+    const QString agentHeaptrack = akGetEnv("AKONADI_HEAPTRACK");
+    if (!agentHeaptrack.isEmpty() && (mApplication.contains(agentHeaptrack) || listContains(mArguments, agentHeaptrack))) {
+
+        mArguments.prepend(mApplication);
+        const QString originalArguments = mArguments.join(QLatin1Char(' '));
+        mApplication = QStringLiteral("heaptrack");
+
+        qCDebug(AKONADICONTROL_LOG);
+        qCDebug(AKONADICONTROL_LOG) << "============================================================";
+        qCDebug(AKONADICONTROL_LOG) << "ProcessControl: Heaptracking process" << originalArguments;
+        qCDebug(AKONADICONTROL_LOG) << "============================================================";
+        qCDebug(AKONADICONTROL_LOG);
+    }
+
+    const QString agentPerf = akGetEnv("AKONADI_PERF");
+    if (!agentPerf.isEmpty() && (mApplication.contains(agentPerf) || listContains(mArguments, agentPerf))) {
+
+        mArguments.prepend(mApplication);
+        const QString originalArguments = mArguments.join(QLatin1Char(' '));
+        mApplication = QStringLiteral("perf");
+
+        mArguments = QStringList{ QStringLiteral("record"), QStringLiteral("--call-graph"), QStringLiteral("dwarf"), QStringLiteral("--") } + mArguments;
+
+        qCDebug(AKONADICONTROL_LOG);
+        qCDebug(AKONADICONTROL_LOG) << "============================================================";
+        qCDebug(AKONADICONTROL_LOG) << "ProcessControl: Perf-recording process" << originalArguments;
+        qCDebug(AKONADICONTROL_LOG) << "============================================================";
+        qCDebug(AKONADICONTROL_LOG);
+    }
 #endif
 
     mProcess.start(mApplication, mArguments);
