@@ -31,7 +31,7 @@
 #include "itemmodifyjob.h"
 #include "transactionsequence.h"
 #include "itemfetchscope.h"
-#include "helper_p.h"
+
 
 #include "akonadicore_debug.h"
 
@@ -82,7 +82,7 @@ public:
     void requestTransaction();
     Job *subjobParent() const;
     void fetchLocalItemsToDelete();
-    QString jobDebuggingString() const Q_DECL_OVERRIDE;
+    QString jobDebuggingString() const override;
     bool allProcessed() const;
 
     Q_DECLARE_PUBLIC(ItemSync)
