@@ -72,10 +72,10 @@ public:
     /** Returns @c true if permanent cache verification is enabled. */
     bool verifyCacheOnRetrieval() const;
 
-    Protocol::Command readCommand();
+    Protocol::CommandPtr readCommand();
 
 public Q_SLOTS:
-    virtual void sendResponse(const Protocol::Command &response);
+    virtual void sendResponse(const Protocol::CommandPtr &response);
 
 Q_SIGNALS:
     void disconnected();
@@ -94,8 +94,8 @@ protected Q_SLOTS:
 protected:
     Connection(QObject *parent = nullptr); // used for testing
 
-    virtual void init() Q_DECL_OVERRIDE;
-    virtual void quit() Q_DECL_OVERRIDE;
+    virtual void init() override;
+    virtual void quit() override;
 
     virtual Handler *findHandlerForCommand(Protocol::Command::Type cmd);
 
@@ -120,7 +120,7 @@ protected:
     bool m_connectionClosing;
 
 private:
-    void sendResponse(qint64 tag, const Protocol::Command &response);
+    void sendResponse(qint64 tag, const Protocol::CommandPtr &response);
 
     /** For debugging */
     void startTime();
