@@ -39,9 +39,9 @@ class Q_DECL_HIDDEN CollectionRequester::Private
 public:
     Private(CollectionRequester *parent)
         : q(parent)
-        , edit(0)
-        , button(0)
-        , collectionDialog(0)
+        , edit(nullptr)
+        , button(nullptr)
+        , collectionDialog(nullptr)
     {
     }
 
@@ -99,7 +99,8 @@ void CollectionRequester::Private::_k_collectionsNamesReceived(KJob *job)
     const qint64 originalId = fetch->property("OriginalCollectionId").toLongLong();
 
     QMap<qint64, Collection> names;
-    Q_FOREACH (const Collection &collection, fetch->collections()) {
+    const Akonadi::Collection::List lstCols = fetch->collections();
+    for (const Collection &collection : lstCols) {
         names.insert(collection.id(), collection);
     }
 
@@ -109,7 +110,7 @@ void CollectionRequester::Private::_k_collectionsNamesReceived(KJob *job)
         namesList.prepend(currentCollection.displayName());
         currentCollection = names.take(currentCollection.parentCollection().id());
     }
-    edit->setText(namesList.join(QStringLiteral("/")));
+    edit->setText(namesList.join(QLatin1Char('/')));
 }
 
 void CollectionRequester::Private::init()
