@@ -36,7 +36,7 @@ using namespace Akonadi;
 struct Q_DECL_HIDDEN TagManagementDialog::Private {
     Private(QDialog *parent)
         : d(parent),
-          buttonBox(0)
+          buttonBox(nullptr)
     {
     }
     void writeConfig();
@@ -73,7 +73,7 @@ TagManagementDialog::TagManagementDialog(QWidget *parent)
     Akonadi::TagModel *model = new Akonadi::TagModel(monitor, this);
     vbox->addWidget(new Akonadi::TagEditWidget(model, this, false));
 
-    d->buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    d->buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     connect(d->buttonBox, &QDialogButtonBox::accepted, this, &TagManagementDialog::accept);
     connect(d->buttonBox, &QDialogButtonBox::rejected, this, &TagManagementDialog::reject);
 
@@ -90,7 +90,7 @@ TagManagementDialog::~TagManagementDialog()
     d->writeConfig();
 }
 
-QDialogButtonBox *TagManagementDialog::buttons()
+QDialogButtonBox *TagManagementDialog::buttons() const
 {
     return d->buttonBox;
 }
